@@ -9,7 +9,7 @@ def install_proto():
     cwd = Path(pkg_resources.resource_filename("grebble_flow", "")).parents[0]
     proto_include = pkg_resources.resource_filename("grebble_flow", "grpc/proto/")
     python_out = pkg_resources.resource_filename("grebble_flow", "grpc/base/")
-    for file in ["processor.proto", "app.proto"]:
+    for file in ["processor_external.proto", "app_external.proto"]:
         grpc_tools.protoc.main(
             [
                 "grpc_tools.protoc",
