@@ -1,11 +1,11 @@
 import json
 
-from grebble_flow.grpc.proto import processor_pb2_grpc, processor_pb2
+from grebble_flow.grpc.proto import processor_external_pb2_grpc, processor_external_pb2
 from grebble_flow.helpers.converter import grebble_converter
 from grebble_flow.managment.manager import FlowManager
 
 
-class ProcessorService(processor_pb2_grpc.ProcessorServicer):
+class ProcessorService(processor_external_pb2_grpc.ExternalProcessorServicer):
     def __init__(self, *args, **kwargs):
         self.flow_manager = FlowManager()
 
@@ -24,10 +24,12 @@ class ProcessorService(processor_pb2_grpc.ProcessorServicer):
         except:
             pass
         for item in self.flow_manager.run(flow_name, content, attributes):
-            yield processor_pb2.FlowResponse(
+            yield processor_external_pb2.FlowResponse(
                 attributes=json.dumps(item.attributes, default=grebble_converter),
                 content=json.dumps(item.content, default=grebble_converter),
                 streamEnd=False,
             )
 
-        yield processor_pb2.FlowResponse(data=None, attributes=None, streamEnd=True)
+        yield processor_external_pb2.FlowResponse(
+            data=None, attributes=None, streamEnd=True
+        )
